import threading


__version__ = '1.0.4'


def it(*objects, token='', silent=False, sep=' '):
    import requests

    if type(token) is not str or token is None:
        raise TypeError('token must be a string, not %r' % token.__class__.__name__)
    if type(silent) is not bool:
        raise TypeError('silent must be None or a bool, not %r' % silent.__class__.__name__)
    if type(sep) is not str:
        raise TypeError('sep must be None or a string, not %r' % sep.__class__.__name__)

    payload = {
        'token': token,
        'text': sep.join(objects),
        'silent': str(silent).lower(),
    }
    thread = threading.Thread(target=requests.post,
                              args=('https://api.puzh.it',),
                              kwargs=dict(json=payload, timeout=60))
    thread.start()



from setuptools import setup
from puzh import __version__


with open('README.rst') as file:
    readme = file.read()

setup(name='puzh',
      packages=['puzh'],
      version=__version__,
      author='lmittmann',
      description='Easily send messages to telegram',
      long_description=readme,
      keywords=['puzh', 'push', 'telegram', 'bot', 'notification'],
      url='https://github.com/puzh/puzh.py',
      license='MIT',
      python_requires='>=3',
      install_requires=['requests>=2.4.2'],
      classifiers=['Development Status :: 4 - Beta',
                   'Intended Audience :: Developers',
                   'License :: OSI Approved :: MIT License',
                   'Natural Language :: English',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.5',
                   'Programming Language :: Python :: 3.6'])
